#####################################################################
#####    Tree-Structured Clustering in Fixed Effects Models     #####
#####                Electronic Supplement                      #####
#####################################################################
#####     Author: Moritz Berger                                 #####
#####################################################################
#####     Content: Auxiliary function to compute                ##### 
#####              FPR and FNR                                  ##### 
#####################################################################


### Function FP_FN() ###

## Input 
# beta_true: true regression coefficients 
# partition_hat: estimated partition of unit-specific intercepts 

## Description 
# The function computes the false positive rate and 
# the false negative rate for one estimated partition. 
# The function is used in the files "program....R". 

## Output 
# FPR and FNR 

FP_FN <- function(beta_true,partition_hat){
  
  n_levels <- length(beta_true)

  dif_matrix <- matrix(1,nrow=n_levels,ncol=n_levels)
  for(i in 1:n_levels){
    dif <- beta_true - beta_true[i] 
    dif_matrix[i,which(dif==0)] <- 0 
  }
  
  
  dif_matrix_hat <- matrix(1,nrow=n_levels,ncol=n_levels)
  for(i in 1:n_levels){
    dif <- partition_hat - partition_hat[i]
    dif_matrix_hat[i,which(dif==0)] <-0 
  }
 
  fp <- length(which((dif_matrix==0) & (dif_matrix_hat==1)))
  fn <- length(which((dif_matrix==1) & (dif_matrix_hat==0)))

  FPR <- fp/(length(which((dif_matrix==0)))-n_levels)
  FNR <- fn/length(which((dif_matrix==1)))
  
  return(c(FPR,FNR))
  
}
