#####################################################################
#####    Tree-Structured Clustering in Fixed Effects Models     #####
#####              Electronic Supplement                        #####
#####################################################################
#####     Author:  Moritz Berger                                #####
#####################################################################
#####     Content: R-Code of the simulation                     #####
#####              in Section 6.1 Normal Response               ##### 
#####################################################################

### Description ### 

# The following contains all the R-Code of Figures 5-7 in Section 6.1 
# and of Table 5 in Appendix B. This corresponds to the simulations 
# with normal response and normally distributed intercepts. 

### Generic function box_results() for the visualization of the results ### 

box_results <- function(lists,col,lines=NULL,labels=TRUE,adj_names=0.15,...){
  
  if(length(adj_names==1)){
    adj_names <- rep(adj_names,length(lists))
  }
  
  for(i in 1:length(lists)){
    to_plot <- t(sapply(1:100, function(j) lists[[i]][[j]][c(1,3,2,6,4,5),col]))
    boxplot(to_plot,bg=grey(0.8),names=FALSE,col=grey(0.8),pch=21,cex.names=1.5,cex.axis=1.8,...)
    if(!is.null(lines)){
      abline(h=lines[i],lty="dashed",lwd=2)
    }
    text(1:6,par("usr")[3]-adj_names[i], 
         srt = 45, adj= 1, xpd=1,
         labels = c("GFM","GMM","TSC","PENL","FINA","FINB"), cex=2)
  }
  if(labels){
    mtext(bquote(m[0]=="5"),side=2,at=0.8,line=0,outer=TRUE,las=2,cex=1.5)
    mtext(bquote(m[0]=="10"),side=2,at=0.3,line=0,outer=TRUE,las=2,cex=1.5)
    mtext(bquote(n=="200"~"/"~n[i]=="4"),side=3,at=0.13,line=-1,outer=TRUE,cex=1.5)
    mtext(bquote(n=="100"~"/"~n[i]=="8"),side=3,at=0.38,line=-1,outer=TRUE,cex=1.5)
    mtext(bquote(n=="40"~"/"~n[i]=="20"),side=3,at=0.63,line=-1,outer=TRUE,cex=1.5)
    mtext(bquote(n=="20"~"/"~n[i]=="40"),side=3,at=0.88,line=-1,outer=TRUE,cex=1.5)
  }
}

### load all the .rda-files containing the results of the simulation ### 

load("./Simulation6.1/raw_results6.1/no_0_5_2004.rda")
load("./Simulation6.1/raw_results6.1/no_0_10_2004.rda")
load("./Simulation6.1/raw_results6.1/no_0_5_1008.rda")
load("./Simulation6.1/raw_results6.1/no_0_10_1008.rda")
load("./Simulation6.1/raw_results6.1/no_0_5_4020.rda")
load("./Simulation6.1/raw_results6.1/no_0_10_4020.rda")
load("./Simulation6.1/raw_results6.1/no_0_5_2040.rda")
load("./Simulation6.1/raw_results6.1/no_0_10_2040.rda")

lists0 <- list(no_0_5_2004,no_0_5_1008,no_0_5_4020,no_0_5_2040,no_0_10_2004,no_0_10_1008,no_0_10_4020,no_0_10_2040)

load("./Simulation6.1/raw_results6.1/no_0.8_5_2004.rda")
load("./Simulation6.1/raw_results6.1/no_0.8_10_2004.rda")
load("./Simulation6.1/raw_results6.1/no_0.8_5_1008.rda")
load("./Simulation6.1/raw_results6.1/no_0.8_10_1008.rda")
load("./Simulation6.1/raw_results6.1/no_0.8_5_4020.rda")
load("./Simulation6.1/raw_results6.1/no_0.8_10_4020.rda")
load("./Simulation6.1/raw_results6.1/no_0.8_5_2040.rda")
load("./Simulation6.1/raw_results6.1/no_0.8_10_2040.rda")

lists0.8 <- list(no_0.8_5_2004,no_0.8_5_1008,no_0.8_5_4020,no_0.8_5_2040,no_0.8_10_2004,no_0.8_10_1008,no_0.8_10_4020,no_0.8_10_2040)

###########################################################################

### Figure 5 (upper panel) ###
par(mfrow=c(2,4),mar=c(5,3,1,1),oma=c(0,7,7,0))
box_results(lists0,1,ylim=c(0,3))
mtext(bquote(rho=="0"),side=3,line=3,outer=TRUE,at=0,cex=1.5,lwd=1.8)
mtext("MSE - intercepts",side=3,line=4,outer=TRUE,cex=2)


### Figure 6 (upper panel) ### 
par(mfrow=c(2,4),mar=c(5,3,1,1),oma=c(0,7,7,0))
box_results(lists0.8,1,ylim=c(0,3))
mtext(bquote(rho=="0.8"),side=3,line=3,outer=TRUE,at=0,cex=1.5,lwd=1.8)
mtext("MSE - intercepts",side=3,line=4,outer=TRUE,cex=2)


### Figure 5 (lower panel) ### 
par(mfrow=c(2,4),mar=c(5,3,1,1),oma=c(0,7,7,0))
box_results(lists0,2,ylim=c(0,0.8),adj_names=0.05)
mtext(bquote(rho=="0"),side=3,line=3,outer=TRUE,at=0,cex=1.5,lwd=1.8)
mtext("MSE - linear term",side=3,line=4,outer=TRUE,cex=2)


### Figure 6 (lower panel) ### 
par(mfrow=c(2,4),mar=c(5,3,1,1),oma=c(0,7,7,0))
box_results(lists0.8,2,ylim=c(0,0.8),adj_names=0.05)
mtext(bquote(rho=="0.8"),side=3,line=3,outer=TRUE,at=0,cex=1.5,lwd=1.8)
mtext("MSE - linear term",side=3,line=4,outer=TRUE,cex=2)


### Figure 7 (upper panel) ### 
par(mfrow=c(2,4),mar=c(5,3,1,1),oma=c(0,7,7,0))
box_results(lists0,5,lines=c(5,5,5,5,10,10,10,10,20,20,20,20),adj_names=rep(c(10,5,2,1),3))
mtext(bquote(rho=="0"),side=3,line=3,outer=TRUE,at=0,cex=1.5,lwd=1.8)
mtext("Number of clusters",side=3,line=4,outer=TRUE,cex=2)


### Figure 7 (lower panel) ### 
par(mfrow=c(2,4),mar=c(5,3,1,1),oma=c(0,7,7,0))
box_results(lists0.8,5,lines=c(5,5,5,5,10,10,10,10,20,20,20,20),adj_names=rep(c(10,5,2,1),3))
mtext(bquote(rho=="0.8"),side=3,line=3,outer=TRUE,at=0,cex=1.5,lwd=1.8)
mtext("Number of clusters",side=3,line=4,outer=TRUE,cex=2)


### Average FPR/FNR given in Table 5  ### 
one_column <- function(list,col){
  erg <- matrix(NA,nrow=6,ncol=100)
  for(i in 1:100){
    erg[,i] <- list[[i]][c(1,3,2,6,4,5),col]
  }
  erg <- apply(erg,1,mean)
  return(erg)
}
one_row <- function(list1,list2){
  erg <- cbind(one_column(list1,3),one_column(list1,4),one_column(list2,3),one_column(list2,4))
  return(erg)
}

### Table 5 (left part) ### 
tab0 <- rbind(one_row(no_0_5_2004,no_0_10_2004),one_row(no_0_5_1008,no_0_10_1008),one_row(no_0_5_4020,no_0_10_4020),one_row(no_0_5_2040,no_0_10_2040))
tab0

### Table 5 (right part) ### 
tab8 <- rbind(one_row(no_0.8_5_2004,no_0.8_10_2004),one_row(no_0.8_5_1008,no_0.8_10_1008),one_row(no_0.8_5_4020,no_0.8_10_4020),one_row(no_0.8_5_2040,no_0.8_10_2040))
tab8






