#####################################################################
#####    Tree-Structured Clustering in Fixed Effects Models     #####
#####              Electronic Supplement                        #####
#####################################################################
#####     Author:  Moritz Berger                                #####
#####################################################################
#####     Content: R-Code of the simulation                     #####
#####              in Section 6.2 Binary Response               ##### 
#####################################################################

### Description ### 

# The following contains all the R-Code of Figures 12-13 in Appendix B. 
# This corresponds to the simulations with binary response and 
# normally distributed intercepts. 

### Generic function box_results() for the visualization of the results ### 

box_results <- function(lists,col,lines=NULL,labels=TRUE,adj_names=0.15,...){
  
  if(length(adj_names==1)){
    adj_names <- rep(adj_names,length(lists))
  }
  
  for(i in 1:length(lists)){
    to_plot <- t(sapply(1:100, function(j) lists[[i]][[j]][c(1,3,2,6,4,5),col]))
    to_plot[,1] <- NA
    boxplot(to_plot,bg=grey(0.8),names=FALSE,col=grey(0.8),pch=21,cex.names=1.5,cex.axis=1.8,...)
    if(!is.null(lines)){
      abline(h=lines[i],lty="dashed",lwd=2)
    }
    text(1:6,par("usr")[3]-adj_names[i], 
         srt = 45, adj= 1, xpd=1,
         labels = c("GFM","GMM","TSC","PENL","FINA","FINB"), cex=2)
  }
  if(labels){
    mtext(bquote(m[0]=="5"),side=2,at=0.8,line=0,outer=TRUE,las=2,cex=1.5)
    mtext(bquote(m[0]=="10"),side=2,at=0.3,line=0,outer=TRUE,las=2,cex=1.5)
    mtext(bquote(n=="100"~"/"~n[i]=="8"),side=3,at=0.18,line=-1,outer=TRUE,cex=1.5)
    mtext(bquote(n=="40"~"/"~n[i]=="20"),side=3,at=0.51,line=-1,outer=TRUE,cex=1.5)
    mtext(bquote(n=="20"~"/"~n[i]=="40"),side=3,at=0.85,line=-1,outer=TRUE,cex=1.5)
  }
}

### load all the .rda-files containing the results of the simulation ### 

load("./Simulation6.2/raw_results6.2/no_0_5_1008.rda")
load("./Simulation6.2/raw_results6.2/no_0_10_1008.rda")
load("./Simulation6.2/raw_results6.2/no_0_5_4020.rda")
load("./Simulation6.2/raw_results6.2/no_0_10_4020.rda")
load("./Simulation6.2/raw_results6.2/no_0_5_2040.rda")
load("./Simulation6.2/raw_results6.2/no_0_10_2040.rda")

lists0 <- list(no_0_5_1008,no_0_5_4020,no_0_5_2040,no_0_10_1008,no_0_10_4020,no_0_10_2040)

load("./Simulation6.2/raw_results6.2/no_0.8_5_1008.rda")
load("./Simulation6.2/raw_results6.2/no_0.8_10_1008.rda")
load("./Simulation6.2/raw_results6.2/no_0.8_5_4020.rda")
load("./Simulation6.2/raw_results6.2/no_0.8_10_4020.rda")
load("./Simulation6.2/raw_results6.2/no_0.8_5_2040.rda")
load("./Simulation6.2/raw_results6.2/no_0.8_10_2040.rda")

lists0.8 <- list(no_0.8_5_1008,no_0.8_5_4020,no_0.8_5_2040,no_0.8_10_1008,no_0.8_10_4020,no_0.8_10_2040)

###########################################################################

### Figure 12 (upper panel) ### 
par(mfrow=c(2,3),mar=c(5,3,1,1),oma=c(0,7,7,0))
box_results(lists0,1,adj_names=2,ylim=c(0,50))
mtext(bquote(rho=="0"),side=3,line=3,outer=TRUE,at=0,cex=1.5,lwd=1.8)
mtext("MSE - intercepts",side=3,line=4,outer=TRUE,cex=2)


### Figure 13 (upper panel) ### 
par(mfrow=c(2,3),mar=c(5,3,1,1),oma=c(0,7,7,0))
box_results(lists0.8,1,adj_names=2,ylim=c(0,50))
mtext(bquote(rho=="0.8"),side=3,line=3,outer=TRUE,at=0,cex=1.5,lwd=1.8)
mtext("MSE - intercepts",side=3,line=4,outer=TRUE,cex=2)


### Figure 12 (middle panel) ### 
par(mfrow=c(2,3),mar=c(5,3,1,1),oma=c(0,7,7,0))
box_results(lists0,2,adj_names=0.04,ylim=c(0,1.2))
mtext(bquote(rho=="0"),side=3,line=3,outer=TRUE,at=0,cex=1.5,lwd=1.8)
mtext("MSE - linear term",side=3,line=4,outer=TRUE,cex=2)


### Figure 13 (middle panel) ### 
par(mfrow=c(2,3),mar=c(5,3,1,1),oma=c(0,7,7,0))
box_results(lists0.8,2,adj_names=0.04,ylim=c(0,1.2))
mtext(bquote(rho=="0.8"),side=3,line=3,outer=TRUE,at=0,cex=1.5,lwd=1.8)
mtext("MSE - linear term",side=3,line=4,outer=TRUE,cex=2)


### Figure 12 (lower panel) ### 
par(mfrow=c(2,3),mar=c(5,3,1,1),oma=c(0,7,7,0))
box_results(lists0,5,lines=c(5,5,5,5,10,10,10,10,20,20,20,20),adj_names=rep(c(5,2,1),3))
mtext(bquote(rho=="0"),side=3,line=3,outer=TRUE,at=0,cex=1.5,lwd=1.8)
mtext("Number of clusters",side=3,line=4,outer=TRUE,cex=2)


### Figure 13 (lower panel) ### 
par(mfrow=c(2,3),mar=c(5,3,1,1),oma=c(0,7,7,0))
box_results(lists0.8,5,lines=c(5,5,5,5,10,10,10,10,20,20,20,20),adj_names=rep(c(5,2,1),3))
mtext(bquote(rho=="0.8"),side=3,line=3,outer=TRUE,at=0,cex=1.5,lwd=1.8)
mtext("Number of clusters",side=3,line=4,outer=TRUE,cex=2)


