#####################################################################
#####    Tree-Structured Clustering in Fixed Effects Models     #####
#####              Electronic Supplement                        #####
#####################################################################
#####     Author:  Moritz Berger                                #####
#####################################################################
#####     Content: R-Code of the simulation                     #####
#####              in Section 6.3 Unbalanced Design             ##### 
#####################################################################

### Description ### 

# The following contains all the R-Code of Figures 15-16 in Appendix B. 
# This corresponds to the simulations with normal response 
# and normally distributed intercepts with unbalanced design. 

### Generic function box_results() for the visualization of the results ### 

box_results <- function(lists,col,lines=NULL,labels=TRUE,adj_names=0.15,...){
  
  if(length(adj_names==1)){
    adj_names <- rep(adj_names,length(lists))
  }
  
  for(i in 1:length(lists)){
    to_plot <- t(sapply(1:100, function(j) lists[[i]][[j]][c(1,3,2,6,4,5),col]))
    boxplot(to_plot,bg=grey(0.8),names=FALSE,col=grey(0.8),pch=21,cex.names=1.5,cex.axis=1.8,...)
    if(!is.null(lines)){
      abline(h=lines[i],lty="dashed",lwd=2)
    }
    text(1:6,par("usr")[3]-adj_names[i], 
         srt = 45, adj= 1, xpd=1,
         labels = c("GFM","GMM","TSC","PENL","FINA","FINB"), cex=2)
  }
  if(labels){
    mtext(bquote(m[0]=="5"),side=2,at=0.8,line=0,outer=TRUE,las=2,cex=1.5)
    mtext(bquote(m[0]=="10"),side=2,at=0.3,line=0,outer=TRUE,las=2,cex=1.5)
    mtext(bquote(n=="200"),side=3,at=0.14,line=-1,outer=TRUE,cex=1.5)
    mtext(bquote(n=="100"),side=3,at=0.39,line=-1,outer=TRUE,cex=1.5)
    mtext(bquote(n=="40"),side=3,at=0.64,line=-1,outer=TRUE,cex=1.5)
    mtext(bquote(n=="20"),side=3,at=0.89,line=-1,outer=TRUE,cex=1.5)
  }
}

### load all the .rda-files containing the results of the simulation ### 

load("./Simulation6.3/raw_results6.3/no_0_5_200.rda")
load("./Simulation6.3/raw_results6.3/no_0_10_200.rda")
load("./Simulation6.3/raw_results6.3/no_0_5_100.rda")
load("./Simulation6.3/raw_results6.3/no_0_10_100.rda")
load("./Simulation6.3/raw_results6.3/no_0_5_40.rda")
load("./Simulation6.3/raw_results6.3/no_0_10_40.rda")
load("./Simulation6.3/raw_results6.3/no_0_5_20.rda")
load("./Simulation6.3/raw_results6.3/no_0_10_20.rda")

lists0 <- list(no_0_5_200,no_0_5_100,no_0_5_40,no_0_5_20,no_0_10_200,no_0_10_100,no_0_10_40,no_0_10_20)

load("./Simulation6.3/raw_results6.3/no_0.8_5_200.rda")
load("./Simulation6.3/raw_results6.3/no_0.8_10_200.rda")
load("./Simulation6.3/raw_results6.3/no_0.8_5_100.rda")
load("./Simulation6.3/raw_results6.3/no_0.8_10_100.rda")
load("./Simulation6.3/raw_results6.3/no_0.8_5_40.rda")
load("./Simulation6.3/raw_results6.3/no_0.8_10_40.rda")
load("./Simulation6.3/raw_results6.3/no_0.8_5_20.rda")
load("./Simulation6.3/raw_results6.3/no_0.8_10_20.rda")

lists0.8 <- list(no_0.8_5_200,no_0.8_5_100,no_0.8_5_40,no_0.8_5_20,no_0.8_10_200,no_0.8_10_100,no_0.8_10_40,no_0.8_10_20)

###########################################################################

### Figure 15 (upper panel) ### 
par(mfrow=c(2,4),mar=c(5,3,1,1),oma=c(0,7,7,0))
box_results(lists0,1,ylim=c(0,3.6))
mtext(bquote(rho=="0"),side=3,line=3,outer=TRUE,at=0,cex=1.5,lwd=1.8)
mtext("MSE - intercepts",side=3,line=4,outer=TRUE,cex=2)


### Figure 16 (upper panel) ### 
par(mfrow=c(2,4),mar=c(5,3,1,1),oma=c(0,7,7,0))
box_results(lists0.8,1,ylim=c(0,3.6))
mtext(bquote(rho=="0.8"),side=3,line=3,outer=TRUE,at=0,cex=1.5,lwd=1.8)
mtext("MSE - intercepts",side=3,line=4,outer=TRUE,cex=2)


### Figure 15 (middle panel) ### 
par(mfrow=c(2,4),mar=c(5,3,1,1),oma=c(0,7,7,0))
box_results(lists0,2,ylim=c(0,0.8),adj_names=0.05)
mtext(bquote(rho=="0"),side=3,line=3,outer=TRUE,at=0,cex=1.5,lwd=1.8)
mtext("MSE - linear term",side=3,line=4,outer=TRUE,cex=2)


### Figure 16 (middle panel) ### 
par(mfrow=c(2,4),mar=c(5,3,1,1),oma=c(0,7,7,0))
box_results(lists0.8,2,ylim=c(0,0.8),adj_names=0.05)
mtext(bquote(rho=="0.8"),side=3,line=3,outer=TRUE,at=0,cex=1.5,lwd=1.8)
mtext("MSE - linear term",side=3,line=4,outer=TRUE,cex=2)


### Figure 15 (lower panel) ### 
par(mfrow=c(2,4),mar=c(5,3,1,1),oma=c(0,7,7,0))
box_results(lists0,5,lines=c(5,5,5,5,10,10,10,10,20,20,20,20),adj_names=rep(c(10,5,2,1),3))
mtext(bquote(rho=="0"),side=3,line=3,outer=TRUE,at=0,cex=1.5,lwd=1.8)
mtext("Number of clusters",side=3,line=4,outer=TRUE,cex=2)


### Figure 16 (lower panel) ### 
par(mfrow=c(2,4),mar=c(5,3,1,1),oma=c(0,7,7,0))
box_results(lists0.8,5,lines=c(5,5,5,5,10,10,10,10,20,20,20,20),adj_names=rep(c(10,5,2,1),3))
mtext(bquote(rho=="0.8"),side=3,line=3,outer=TRUE,at=0,cex=1.5,lwd=1.8)
mtext("Number of clusters",side=3,line=4,outer=TRUE,cex=2)



