#####################################################################
#####    Tree-Structured Clustering in Fixed Effects Models     #####
#####              Electronic Supplement                        #####
#####################################################################
#####     Author:  Moritz Berger                                #####
#####################################################################
#####     Content: R-Code of the simulation                     #####
#####              in Section 6.4 Extreme Settings              ##### 
#####################################################################

### Description ### 

# The following contains all the R-Code of Figures 17-18 in Appendix B. 
# This corresponds to the extreme settings with normal response 
# and normally distributed intercepts. 

### Generic function box_results() for the visualization of the results ### 

box_results <- function(lists,col,lines=NULL,labels=TRUE,adj_names=0.15,one=TRUE,...){
  
  if(length(adj_names==1)){
    adj_names <- rep(adj_names,length(lists))
  }
  
  for(i in 1:length(lists)){
    to_plot <- t(sapply(1:100, function(j) lists[[i]][[j]][c(1,3,2,6,4,5),col]))
    boxplot(to_plot,bg=grey(0.8),names=FALSE,col=grey(0.8),pch=21,cex.names=1.5,cex.axis=1.8,...)
    if(!is.null(lines)){
      abline(h=lines[i],lty="dashed",lwd=2)
    }
    text(1:6,par("usr")[3]-adj_names[i], 
         srt = 45, adj= 1, xpd=1,
         labels = c("GFM","GMM","TSC","PENL","FINA","FINB"), cex=2)
  }
  if(labels){
    if(one){
      mtext(bquote(m[0]=="1"),side=2,at=0.8,line=0,outer=TRUE,las=2,cex=1.5)
      mtext(bquote(m[0]=="n"),side=2,at=0.3,line=0,outer=TRUE,las=2,cex=1.5)
    } else{
      mtext(bquote(m[0]=="n"),side=2,at=0.5,line=0,outer=TRUE,las=2,cex=1.5)
    }
    mtext(bquote(n=="200"~"/"~n[i]=="4"),side=3,at=0.13,line=-1,outer=TRUE,cex=1.5)
    mtext(bquote(n=="100"~"/"~n[i]=="8"),side=3,at=0.38,line=-1,outer=TRUE,cex=1.5)
    mtext(bquote(n=="40"~"/"~n[i]=="20"),side=3,at=0.63,line=-1,outer=TRUE,cex=1.5)
    mtext(bquote(n=="20"~"/"~n[i]=="40"),side=3,at=0.88,line=-1,outer=TRUE,cex=1.5)
  }
}

### load all the .rda-files containing the results of the simulation ### 

load("./Simulation6.4/raw_results6.4/no_0_0_2004.rda")
load("./Simulation6.4/raw_results6.4/no_0_1_2004.rda")
load("./Simulation6.4/raw_results6.4/no_0_0_1008.rda")
load("./Simulation6.4/raw_results6.4/no_0_1_1008.rda")
load("./Simulation6.4/raw_results6.4/no_0_0_4020.rda")
load("./Simulation6.4/raw_results6.4/no_0_1_4020.rda")
load("./Simulation6.4/raw_results6.4/no_0_0_2040.rda")
load("./Simulation6.4/raw_results6.4/no_0_1_2040.rda")

lists0 <- list(no_0_1_2004,no_0_1_1008,no_0_1_4020,no_0_1_2040,no_0_0_2004,no_0_0_1008,no_0_0_4020,no_0_0_2040)

load("./Simulation6.4/raw_results6.4/no_0.8_0_2004.rda")
load("./Simulation6.4/raw_results6.4/no_0.8_0_1008.rda")
load("./Simulation6.4/raw_results6.4/no_0.8_0_4020.rda")
load("./Simulation6.4/raw_results6.4/no_0.8_0_2040.rda")

lists0.8 <- list(no_0.8_0_2004,no_0.8_0_1008,no_0.8_0_4020,no_0.8_0_2040)

###########################################################################

### Figure 17 (upper panel) ### 
par(mfrow=c(2,4),mar=c(5,3,1,1),oma=c(0,7,7,0))
box_results(lists0,1,ylim=c(0,3))
mtext(bquote(rho=="0"),side=3,line=3,outer=TRUE,at=0,cex=1.5,lwd=1.8)
mtext("MSE - intercepts",side=3,line=4,outer=TRUE,cex=2)


### Figure 18 (upper panel) ### 
par(mfrow=c(1,4),mar=c(5,3,1,1),oma=c(0,7,7,0))
box_results(lists0.8,1,ylim=c(0,3), adj_names=0.05,one=FALSE)
mtext(bquote(rho=="0.8"),side=3,line=3,outer=TRUE,at=0,cex=1.5,lwd=1.8)
mtext("MSE - intercepts",side=3,line=4,outer=TRUE,cex=2)


### Figure 17 (middle panel) ### 
par(mfrow=c(2,4),mar=c(5,3,1,1),oma=c(0,7,7,0))
box_results(lists0,2,ylim=c(0,0.8),adj_names=0.05)
mtext(bquote(rho=="0"),side=3,line=3,outer=TRUE,at=0,cex=1.5,lwd=1.8)
mtext("MSE - linear term",side=3,line=4,outer=TRUE,cex=2)


### Figure 18 (middle panel) ### 
par(mfrow=c(1,4),mar=c(5,3,1,1),oma=c(0,7,7,0))
box_results(lists0.8,2,ylim=c(0,0.8),adj_names=0.01,one=FALSE)
mtext(bquote(rho=="0.8"),side=3,line=3,outer=TRUE,at=0,cex=1.5,lwd=1.8)
mtext("MSE - linear term",side=3,line=4,outer=TRUE,cex=2)


### Figure 17 (lower panel) ### 
par(mfrow=c(2,4),mar=c(5,3,1,1),oma=c(0,7,7,0))
box_results(lists0,5,lines=c(1,1,1,1,200,100,40,20),adj_names=rep(c(10,5,2,1),2))
mtext(bquote(rho=="0"),side=3,line=3,outer=TRUE,at=0,cex=1.5,lwd=1.8)
mtext("Number of clusters",side=3,line=4,outer=TRUE,cex=2)


### Figure 18 (lower panel) ### 
par(mfrow=c(1,4),mar=c(5,3,1,1),oma=c(0,7,7,0))
box_results(lists0.8,5,lines=c(200,100,40,20),adj_names=c(3,1.5,0.5,0.25), one=FALSE)
mtext(bquote(rho=="0.8"),side=3,line=3,outer=TRUE,at=0,cex=1.5,lwd=1.8)
mtext("Number of clusters",side=3,line=4,outer=TRUE,cex=2)




