#####################################################################
#####    Tree-Structured Clustering in Fixed Effects Models     #####
#####              Electronic Supplement                        #####
#####################################################################
#####     Author:  Moritz Berger                                #####
#####################################################################
#####     Content: R-Code of the simulated bootstrap            #####
#####              confidence intervals in Section 4            ##### 
#####################################################################

### Description ###  

# The following contains all the R-Code of Figure 4 in Section 4. 
# This corresponds to the simulated bootstrap confidence intervals. 
# The results show a coverage of 0.946. 


### load the .rda-file containing the results of the simulation ### 
load("./simulationBoot/raw_resultsBoot/simulation_boot.rda")


### calculate coverage ### 
inside <- function(res){
  hit <- (res[1,]< -2 & res[2,]> -2)
  return(hit)
}
hits <- t(sapply(1:300,function(j) inside(res_boot[[j]])))
apply(hits,2,mean)


### Figure 4 ### 
lb <- sapply(1:300, function(j) res_boot[[j]][1,2])
ub <- sapply(1:300, function(j) res_boot[[j]][2,2])

par(mar=c(0,0,2,0),oma=c(0.5,3,0.5,0.5))
layout(matrix(c(1,2,3),nrow=1,ncol=3),width=c(1/3,2/3,1/3))
boxplot(lb,ylim=c(-3,-1),axes=FALSE,col=grey(0.8),pch=21,bg=grey(0.8),width=1,main=c(expression(q[0.025])),
        cex.axis=1.8,cex.lab=1.5,cex.main=2)
axis(2,cex.axis=1.8)

set.seed(1116)
sam <- sample(300,50)
plot.new()
plot.window(xlim=c(1,50),ylim=c(-3,-1))
for(i in 1:100){
  lines(c(i,i),res_boot[[sam[i]]][,2],type="b",pch=19,lwd=2)
}
abline(h=-2,lty="dashed",lwd=2)

boxplot(ub,ylim=c(-3,-1),axes=FALSE,col=grey(0.8),pch=21,bg=grey(0.8),width=1,main=c(expression(q[0.975])),
        cex.axis=1.8,cex.lab=1.5,cex.main=2)
box(which="inner")
