#####################################################################
#####    Tree-Structured Clustering in Fixed Effects Models     #####
#####              Electronic Supplement                        #####
#####################################################################
#####     Author:  Moritz Berger                                #####
#####################################################################
#####     Content: R-Code of the simulation                     #####
#####              in Appendix B Extension                      ##### 
#####################################################################

### Description ### 

# The following contains all the R-Code of Figure 19 in Appendix B. 
# This corresponds to the simulation with a covariate that is constant 
# across observation units. 

### load the .rda-file containing the results of the simulation ### 
load("./SimulationExtension/raw_resultsExtension/simulation_Extension.rda")

### selecting those results, where PENL worked ### 
valid <- sapply(1:200, function(j) !is.na(res[[j]][5,1]))

### extract results for plotting ### 

# MSE - random intercepts
MSE_bi <- t(sapply(which(valid), function(j) res[[j]][c(2,1,5,3,4),1]))
# MSE - linear term 
MSE_lin <- t(sapply(which(valid), function(j) res[[j]][c(2,1,5,3,4),2]))
# ncluster 
nclu <- t(sapply(which(valid), function(j) res[[j]][c(2,1,5,3,4),5]))


### Figure 11 ### 
par(mfrow=c(1,3),mar=c(7,4,4,1))
boxplot(MSE_bi,ylim=c(0,1),main="MSE - intercepts",bg=grey(0.8),names=FALSE,col=grey(0.8),pch=21,
        cex.names=1.5,cex.axis=3,cex.main=3)
text(1:5,par("usr")[3]-0.03, 
     srt = 45, adj= 1, xpd=1,
     labels = c("GMM","TSC","PENL","FINA","FINB"), cex=3)

boxplot(MSE_lin,ylim=c(0,1),main="MSE - linear term",bg=grey(0.8),names=FALSE,col=grey(0.8),pch=21,
        cex.names=1.5,cex.axis=3,cex.main=3)
text(1:5,par("usr")[3]-0.03, 
     srt = 45, adj= 1, xpd=1,
     labels = c("GMM","TSC","PENL","FINA","FINB"), cex=3)

boxplot(nclu, main="Number of clusters",bg=grey(0.8),names=FALSE,col=grey(0.8),pch=21,
        cex.names=1.5,cex.axis=3,cex.main=3)
abline(h=5,lty="dashed")
text(1:5,par("usr")[3]-0.45, 
     srt = 45, adj= 1, xpd=1,
     labels = c("GMM","TSC","PENL","FINA","FINB"), cex=3)
